# -*- coding: utf-8 -*-
# AUTHOR  : wjia
# TIME    : 2022/6/21 16:02
# FILE    : __init__
# PROJECT : funfunc
# IDE     : PyCharm

# from .cv import *
# from .dl import *
# from .ml import *
# from .nlp import *
# from .tool import *
# from .tornado_helper import *

__VERSION__ = "0.0.5"
__AUTHOR__ = "Wei Jia"
__DESCRIPTION__ = "Make Py Development Much Easier & Fun"
